@@ -1,6 +1,6 @@
 #' @export
 #' @importFrom R.utils getAbsolutePath
-#' @importFrom utils zip
+#' @importFrom zip zip
 #' @title compress a folder
 #' @description compress a folder to a target file. The
 #' function returns the complete path to target file.
@@ -10,18 +10,16 @@
 #' @param target path of the archive to create
 pack_folder <- function( folder, target ){
 
-  target <- getAbsolutePath(target)
-  folder <- getAbsolutePath(folder)
+  target <- getAbsolutePath(path.expand(target))
+  folder <- getAbsolutePath(path.expand(folder))
   curr_wd <- getwd()
   zip_dir <- folder
   setwd(zip_dir)
-  zip(zipfile = target, flags = "-qr9X",
+  zip(zipfile = target,
       files = list.files(all.files = TRUE, recursive = TRUE))
   setwd(curr_wd)
 
   if( !file.exists(target) ){
-    if( Sys.getenv("R_ZIPCMD") == "")
-      stop('A zip application must be available to R. You can set its path with Sys.setenv("R_ZIPCMD" = "path/to/zip")', call. = FALSE)
     msg <- sprintf("could not zip package %s in file %s", shQuote(zip_dir), shQuote(target))
     stop(msg, call. = FALSE)
   }
@@ -41,8 +39,8 @@ pack_folder <- function( folder, target ){
 #' @param folder folder to create
 unpack_folder <- function( file, folder ){
 
-  file <- getAbsolutePath(file)
-  folder <- getAbsolutePath(folder)
+  file <- getAbsolutePath(path.expand(file))
+  folder <- getAbsolutePath(path.expand(folder))
   stopifnot(file.exists(file))
 
   unlink(folder, recursive = TRUE, force = TRUE)
@@ -51,16 +49,3 @@ unpack_folder <- function( file, folder ){
 
   folder
 }
-
-#' @export
-#' @title test zip function
-#' @description test wether zip can produce a zip file.
-#' @examples
-#' has_zip()
-has_zip <- function(){
-  ifile <- tempfile(fileext = ".txt")
-  cat("hi", file = ifile)
-  ofile <- tempfile(fileext = ".zip")
-  try(zip(zipfile = ofile, flags = "-qr9X", files = ifile ), silent = TRUE)
-  file.exists(ofile)
-}
