@@ -177,63 +177,6 @@ presentation <- R6Class(
 )
 
 
-# openxml_document --------------------------------------------------------
-openxml_document <- R6Class(
-  "openxml_document",
-  public = list(
-
-    initialize = function( dir ) {
-      private$reldir = dir
-    },
-
-    feed = function( file ) {
-      private$filename <- file
-      private$rels_filename <- file.path( dirname(file), "_rels", paste0(basename(file), ".rels") )
-
-      private$doc <- read_xml(file)
-      private$rels_doc <- relationship$new()$feed_from_xml(private$rels_filename)
-      self
-    },
-    file_name = function(){
-      private$filename
-    },
-    name = function(){
-      basename(private$filename)
-    },
-    get = function(){
-      private$doc
-    },
-    dir_name = function(){
-      private$reldir
-    },
-    save = function() {
-      write_xml(private$doc, file = private$filename)
-      private$rels_doc$write(private$rels_filename)
-      self
-    },
-    remove = function() {
-      unlink(private$filename)
-      unlink(private$rels_filename)
-      private$filename
-    },
-    rel_df = function(){
-      private$rels_doc$get_data()
-    },
-    relationship = function(){
-      private$rels_doc
-    }
-
-  ),
-  private = list(
-
-    filename = NULL,
-    rels_filename = NULL,
-    doc = NULL,
-    rels_doc = NULL,
-    reldir = NULL
-
-  )
-)
 
 
 # slide master ------------------------------------------------------------
@@ -519,6 +462,11 @@ dir_slide <- R6Class(
     update = function( ){
       dir_ <- file.path(private$package_dir, "ppt/slides")
       filenames <- list.files(path = dir_, pattern = "\\.xml$", full.names = TRUE)
+
+      # order matter here, so lets order file regarding their index
+      sl_id <- as.integer( gsub( "(slide)([0-9]+)(\\.xml)$", "\\2", basename(filenames) ) )
+      filenames <- filenames[order(sl_id)]
+
       private$collection <- map( filenames, function(x, container){
         container$clone()$feed(x)$fortify_id()
       }, container = slide$new("ppt/slides"))
@@ -532,7 +480,7 @@ dir_slide <- R6Class(
       slide_obj$remove()
     },
     get_xfrm = function( ){
-      map(private$collection, function(x, ref) x$get_xfrm() )
+      map(private$collection, function(x) x$get_xfrm() )
     },
 
 
