@@ -11,8 +11,7 @@
 #' doc <- add_slide(doc, layout = "Title and Content", master = "Office Theme")
 #' doc <- ph_empty(x = doc, type = "title")
 #'
-#' if( has_zip() )
-#'   print(doc, target = fileout )
+#' print(doc, target = fileout )
 #' @importFrom xml2 xml_find_first as_xml_document xml_remove
 ph_empty <- function( x, type = "title", index = 1 ){
 
@@ -51,8 +50,7 @@ ph_empty <- function( x, type = "title", index = 1 ){
 #' doc <- ph_with_text(x = doc, type = "subTitle", str = "Un sous titre")
 #' doc <- ph_with_text(x = doc, type = "ctrTitle", str = "Un titre")
 #'
-#' if( has_zip() )
-#'   print(doc, target = fileout )
+#' print(doc, target = fileout )
 #' @importFrom xml2 xml_find_first as_xml_document xml_remove
 ph_with_text <- function( x, str, type = "title", index = 1 ){
 
@@ -83,49 +81,21 @@ ph_with_text <- function( x, str, type = "title", index = 1 ){
 #'   ph_with_table(value = mtcars[1:6,], type = "body",
 #'     last_row = FALSE, last_column = FALSE, first_row = TRUE)
 #'
-#' if( has_zip() )
-#'   print(doc, target = "ph_with_table.pptx")
+#' print(doc, target = "ph_with_table.pptx")
 ph_with_table <- function( x, value, type = "title", index = 1,
                            first_row = TRUE, first_column = FALSE,
                            last_row = FALSE, last_column = FALSE ){
+  stopifnot(is.data.frame(value))
 
   stopifnot( type %in% c("ctrTitle", "subTitle", "dt", "ftr", "sldNum", "title", "body") )
 
   slide <- x$slide$get_slide(x$cursor)
   xfrm_df <- slide$get_xfrm(type = type, index = index)
 
-  def_height <- xfrm_df$cy*914400 / (nrow(value) + 1)
-  def_width <- xfrm_df$cx*914400 / (ncol(value))
+  xml_elt <- table_shape(x = x, value = value, left = xfrm_df$offx, top = xfrm_df$offy, width = xfrm_df$cx, height = xfrm_df$cy,
+                          first_row = first_row, first_column = first_column,
+                          last_row = last_row, last_column = last_column )
 
-
-  style_id <- x$table_styles$def[1]
-  xml_elt <- pml_table(value, style_id = style_id,
-                       col_width = as.integer(def_width),
-                       row_height = as.integer(def_height),
-                       first_row = first_row, last_row = last_row,
-                       first_column = first_column, last_column = last_column )
-
-  xml_elt <- paste0(
-    "<p:graphicFrame ",
-    "xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" ",
-    "xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" ",
-    "xmlns:p=\"http://schemas.openxmlformats.org/presentationml/2006/main\">",
-    "<p:nvGraphicFramePr>",
-    "<p:cNvPr id=\"\" name=\"\"/>",
-    "<p:cNvGraphicFramePr><a:graphicFrameLocks noGrp=\"true\"/></p:cNvGraphicFramePr>",
-    "<p:nvPr/>",
-    "</p:nvGraphicFramePr>",
-    "<p:xfrm rot=\"0\">",
-    sprintf( "<a:off x=\"%.0f\" y=\"%.0f\"/>", xfrm_df$offx*914400, xfrm_df$offy*914400 ),
-    sprintf( "<a:ext cx=\"%.0f\" cy=\"%.0f\"/>", xfrm_df$cx*914400, xfrm_df$cy*914400 ),
-    "</p:xfrm>",
-    "<a:graphic>",
-    "<a:graphicData uri=\"http://schemas.openxmlformats.org/drawingml/2006/table\">",
-    xml_elt,
-    "</a:graphicData>",
-    "</a:graphic>",
-    "</p:graphicFrame>"
-  )
   xml_add_child(xml_find_first(slide$get(), "//p:spTree"), as_xml_document(xml_elt))
   slide$save()
   x$slide$update()
@@ -154,8 +124,7 @@ ph_with_table <- function( x, value, type = "title", index = 1,
 #'   doc <- ph_with_img(x = doc, type = "dt", src = calendar_src )
 #' }
 #'
-#' if( has_zip() )
-#'   print(doc, target = fileout )
+#' print(doc, target = fileout )
 #' @importFrom xml2 xml_find_first as_xml_document xml_remove
 ph_with_img <- function( x, src, type = "body", index = 1, width = NULL, height = NULL ){
 
@@ -231,4 +200,27 @@ ph_from_xml <- function( x, value, type = "body", index = 1 ){
 }
 
 
+#' @export
+#' @rdname ph_from_xml
+#' @param left,top location of the new shape on the slide
+#' @param width,height shape size in inches
+ph_from_xml_at <- function( x, value, left, top, width, height ){
+
+  slide <- x$slide$get_slide(x$cursor)
+
+  doc <- as_xml_document(value)
+  node <- xml_find_first( doc, "//*[self::p:sp or self::p:graphicFrame or self::p:grpSp or self::p:pic]")
+  node <- set_xfrm_attr(node,
+                        offx = left,
+                        offy = top,
+                        cx = width,
+                        cy = height)
+  xml_add_child(xml_find_first(slide$get(), "//p:spTree"), doc)
+
+  slide$fortify_id()$save()
+  x$slide$update()
+  x
+}
+
+
 
